@@ -218,7 +218,7 @@ void MENUS::render_serverbrowser_serverlist(RECT view)
 		}
 		
 		// check if we need to do more
-		if(row.y > original_view.y+original_view.h)
+		if(row.y > original_view.y+original_view.h && !ui_active_item())
 			break;
 
 		for(int c = 0; c < num_cols; c++)
@@ -260,7 +260,7 @@ void MENUS::render_serverbrowser_serverlist(RECT view)
 			else if(id == COL_NAME)
 			{
 				TEXT_CURSOR cursor;
-				gfx_text_set_cursor(&cursor, button.x, button.y, 12.0f, TEXTFLAG_RENDER|TEXTFLAG_STOP_AT_END);
+				gfx_text_set_cursor(&cursor, button.x, button.y, 12.0f*ui_scale(), TEXTFLAG_RENDER|TEXTFLAG_STOP_AT_END);
 				cursor.line_width = button.w;
 				
 				if(config.b_filter_string[0] && (item->quicksearch_hit&BROWSEQUICK_SERVERNAME))
@@ -332,11 +332,16 @@ void MENUS::render_serverbrowser_serverlist(RECT view)
 	ui_margin(&status, 5.0f, &status);
 	
 	// render quick search
-	RECT quicksearch;
+	RECT quicksearch, button;
 	ui_vsplit_l(&status, 250.0f, &quicksearch, &status);
 	ui_do_label(&quicksearch, "Quick search: ", 14.0f, -1);
 	ui_vsplit_l(&quicksearch, gfx_text_width(0, 14.0f, "Quick search: ", -1), 0, &quicksearch);
 	ui_do_edit_box(&config.b_filter_string, &quicksearch, config.b_filter_string, sizeof(config.b_filter_string), 14.0f);
+	ui_vsplit_l(&quicksearch, 135.0f, &quicksearch, &button);
+	ui_vmargin(&button, 0.0f, &button);
+	static int clear_button = 0;
+	if(ui_do_button(&clear_button, "x", 0, &button, ui_draw_menu_button, 0))
+		config.b_filter_string[0] = 0;
 	
 	// render status
 	char buf[128];
@@ -577,7 +582,7 @@ void MENUS::render_serverbrowser(RECT main_view)
 
 	render_serverbrowser_serverlist(view);
 	
-	static int toolbox_page = 0;
+	int toolbox_page = config.ui_toolbox_page;
 	
 	ui_vsplit_l(&toolbox, 5.0f, 0, &toolbox);
 
@@ -599,6 +604,8 @@ void MENUS::render_serverbrowser(RECT main_view)
 		if (ui_do_button(&info_tab, "Info", toolbox_page==1, &tabbutton1, ui_draw_menu_tab_button, 0))
 			toolbox_page = 1;
 	}
+	
+	config.ui_toolbox_page = toolbox_page;
 
 	ui_draw_rect(&toolbox, vec4(0,0,0,0.15f), 0, 0);
 	
